@@ -29,11 +29,28 @@ FIELD_TYPES_DICT = dict(Input='models.CharField',
     DateTime='models.CharField',
     CheckBox='MultiSelectField',
     RadioButton='UncleanedCharField')
+    
+FIELD_TYPE_DEFAULT = 'models.CharField'
+
 
 class UncleanedCharField(models.CharField):
     def clean(self, value, *args):
         # ignore clean
         return value
+        
+    def get_choices(self, include_blank=False):
+        """
+        Overriding the method to remove the 
+        BLANK_OPTION in Checkbox, Radio and Select.
+        
+        * Only if the dfield is blank
+        """
+        choices = []
+        if self.blank:
+            choices = super(UncleanedCharField, self).get_choices()
+        
+        return choices or self._choices
+
 
 class MultiSelectField(UncleanedCharField):
     # XXX: Override formfield
@@ -80,6 +97,7 @@ class DynamicField(models.Model):
     typo = models.CharField(max_length=20, blank=False, verbose_name="Field type",
         choices=single_list_to_tuple(FIELD_TYPES))
     max_length = models.IntegerField(null=True, blank=True, verbose_name="Length")
+    blank = models.BooleanField(default=True, verbose_name="Blank")
     choices = models.TextField(null=True, blank=True, verbose_name="Choices")
     default_value = models.CharField(max_length=80, null=True, blank=True, verbose_name="Default value")
 
@@ -152,11 +170,9 @@ class HStoreModelMeta(models.Model.__metaclass__):
 
                 for metafield in metafields:
                     try:
-                        # TODO: use FIELD_TYPES_DICT.get with default value instead of try/except
-                        try:
-                            field_klass_name = '%s' % FIELD_TYPES_DICT[metafield.typo]
-                        except KeyError:
-                            field_klass_name = 'models.CharField'
+                        field_klass_name = FIELD_TYPES_DICT.get(metafield.typo, 
+                                                                FIELD_TYPE_DEFAULT)
+                        
                         #FIXME: eval is the evil, use module package
                         field_klass = eval(field_klass_name)
                         if metafield.choices == '':
@@ -166,9 +182,10 @@ class HStoreModelMeta(models.Model.__metaclass__):
                                      [s.strip() for s in metafield.choices.splitlines()])
 
                         field = field_klass(name=metafield.name,
-                                            max_length=metafield.max_length,
+                                            max_length=metafield.max_length or 255,
                                             choices=choices_,
                                             default=metafield.default_value,
+                                            verbose_name=metafield.verbose_name,
                                             blank=True,
                                             null=True)
                         field.attname = metafield.name
